@@ -28,9 +28,6 @@ from patchwork.steps.ExtractPackageManagerFile.ExtractPackageManagerFile import
 from patchwork.steps.FileAgent.FileAgent import FileAgent
 from patchwork.steps.FilterBySimilarity.FilterBySimilarity import FilterBySimilarity
 from patchwork.steps.FixIssue.FixIssue import FixIssue
-from patchwork.steps.GetTypescriptTypeInfo.GetTypescriptTypeInfo import (
-    GetTypescriptTypeInfo,
-)
 from patchwork.steps.GitHubAgent.GitHubAgent import GitHubAgent
 from patchwork.steps.JoinList.JoinList import JoinList
 from patchwork.steps.LLM.LLM import LLM
@@ -52,6 +49,7 @@ from patchwork.steps.SendEmail.SendEmail import SendEmail
 from patchwork.steps.SimplifiedLLM.SimplifiedLLM import SimplifiedLLM
 from patchwork.steps.SimplifiedLLMOnce.SimplifiedLLMOnce import SimplifiedLLMOnce
 from patchwork.steps.SlackMessage.SlackMessage import SlackMessage
+from patchwork.steps.ZohoDeskAgent.ZohoDeskAgent import ZohoDeskAgent
 
 # Compatibility Aliases
 JoinListPB = JoinList
@@ -109,7 +107,7 @@ __all__ = [
     "SlackMessage",
     "JoinList",
     "JoinListPB",
-    "GetTypescriptTypeInfo",
     "BrowserUse",
     "ManageEngineAgent",
+    "ZohoDeskAgent",
 ]
